@@ -47,6 +47,9 @@ ADDITIONAL_IGNORE_LIST = []
 CLEAN_PY_IN_REMOTE = False
 CHECK_PIP_REQUIREMENTS = True
 COMPILE_PYC = True
+REMOTE_ENVIRONMENTS = {}
+UPDATE_YUM_PACKAGES = False
+YUM_PACKAGES = []
 
 # Apache
 APACHE_CONF_FILE = lambda: env.project_name
@@ -70,6 +73,7 @@ SERVE_MEDIA = False
 SERVE_ROBOTS = False
 SERVE_STATIC = True
 URL_PREFIX = '/'
+WSGI_SCRIPT_DIR_NAME = lambda: env.project_name
 WSGI_SCRIPT_FILE_NAME = 'wsgi.py'
 WSGI_PROCESS_GROUP = 'apache'
 WSGI_PROCESS_NAME = lambda: env.project_name
