@@ -15,19 +15,12 @@ limitations under the License.
 """
 
 from django.core.exceptions import ValidationError, ImproperlyConfigured
+from eggplant.validators.number import range_validator
 
 def len_validator(target_value, operator):
     def validator(raw_value):
-        if operator not in ('==', '!=', '<=', '>=', '<', '>'):
-            raise ImproperlyConfigured('Operator is invalid.')
-
-        length = len(raw_value)
-        if operator=='==' and length==target_value: return
-        if operator=='!=' and length!=target_value: return
-        if operator=='<=' and length<=target_value: return
-        if operator=='>=' and length>=target_value: return
-        if operator=='<'  and length<target_value:  return
-        if operator=='>'  and length>target_value:  return
-
-        raise ValidationError('The length of \'%s\' %s %s'%(raw_value, operator, target_value))
+        try:
+            range_validator(target_value, operator)(len(raw_value))
+        except ValidationError:
+            raise ValidationError('The length of \'%s\' %s %s'%(raw_value, operator, target_value))
     return validator
